@@ -35,11 +35,7 @@
 #include <tdelistbox.h>
 #include <tdelocale.h>
 #include <kdebug.h>
-#if TDE_VERSION_MAJOR >= 3
-  #include <tdeapplication.h>
-#else
-  #include <kapp.h>
-#endif
+#include <tdeapplication.h>
 #include <tdelistview.h>
 #include <kkeydialog.h>
 #include <tdeconfig.h>
